[−][src]Trait core_foundation::base::TCFType
All Core Foundation types implement this trait. The associated type Ref specifies the
associated Core Foundation type: e.g. for CFType this is CFTypeRef; for CFArray this is
CFArrayRef.
Most structs that implement this trait will do so via the impl_TCFType macro.
Associated Types
type Ref: TCFTypeRef
The reference type wrapped inside this type.
Required methods
fn as_concrete_TypeRef(&self) -> Self::Ref
Returns the object as its concrete TypeRef.
unsafe fn wrap_under_create_rule(obj: Self::Ref) -> Self
Returns an instance of the object, wrapping the underlying CFTypeRef subclass. Use this
when following Core Foundation's "Create Rule". The reference count is not bumped.
fn type_id() -> CFTypeID
Returns the type ID for this class.
fn as_CFTypeRef(&self) -> CFTypeRef
Returns the object as a raw CFTypeRef. The reference count is not adjusted.
unsafe fn wrap_under_get_rule(reference: Self::Ref) -> Self
Returns an instance of the object, wrapping the underlying CFTypeRef subclass. Use this
when following Core Foundation's "Get Rule". The reference count is bumped.
Provided methods
fn as_CFType(&self) -> CFType
Returns the object as a wrapped CFType. The reference count is incremented by one.
fn into_CFType(self) -> CFType where
Self: Sized,
Self: Sized,
Returns the object as a wrapped CFType. Consumes self and avoids changing the reference
count.
fn retain_count(&self) -> CFIndex
Returns the reference count of the object. It is unwise to do anything other than test whether the return value of this method is greater than zero.
fn type_of(&self) -> CFTypeID
Returns the type ID of this object.
fn show(&self)
Writes a debugging version of this object on standard error.
fn instance_of<OtherCFType: TCFType>(&self) -> bool
Returns true if this value is an instance of another type.
Implementors
impl TCFType for CFAttributedString[src]
type Ref = CFAttributedStringRef
fn as_concrete_TypeRef(&self) -> CFAttributedStringRef[src]
unsafe fn wrap_under_get_rule(reference: CFAttributedStringRef) -> Self[src]
fn as_CFTypeRef(&self) -> CFTypeRef[src]
unsafe fn wrap_under_create_rule(reference: CFAttributedStringRef) -> Self[src]
fn type_id() -> CFTypeID[src]
fn as_CFType(&self) -> CFType[src]
fn into_CFType(self) -> CFType where
Self: Sized, [src]
Self: Sized,
fn retain_count(&self) -> CFIndex[src]
fn type_of(&self) -> CFTypeID[src]
fn show(&self)[src]
fn instance_of<OtherCFType: TCFType>(&self) -> bool[src]
impl TCFType for CFMutableAttributedString[src]
type Ref = CFMutableAttributedStringRef
fn as_concrete_TypeRef(&self) -> CFMutableAttributedStringRef[src]
unsafe fn wrap_under_get_rule(reference: CFMutableAttributedStringRef) -> Self[src]
fn as_CFTypeRef(&self) -> CFTypeRef[src]
unsafe fn wrap_under_create_rule(
reference: CFMutableAttributedStringRef
) -> Self[src]
reference: CFMutableAttributedStringRef
) -> Self
fn type_id() -> CFTypeID[src]
fn as_CFType(&self) -> CFType[src]
fn into_CFType(self) -> CFType where
Self: Sized, [src]
Self: Sized,
fn retain_count(&self) -> CFIndex[src]
fn type_of(&self) -> CFTypeID[src]
fn show(&self)[src]
fn instance_of<OtherCFType: TCFType>(&self) -> bool[src]
impl TCFType for CFAllocator[src]
type Ref = CFAllocatorRef
fn as_concrete_TypeRef(&self) -> CFAllocatorRef[src]
unsafe fn wrap_under_get_rule(reference: CFAllocatorRef) -> Self[src]
fn as_CFTypeRef(&self) -> CFTypeRef[src]
unsafe fn wrap_under_create_rule(reference: CFAllocatorRef) -> Self[src]
fn type_id() -> CFTypeID[src]
fn as_CFType(&self) -> CFType[src]
fn into_CFType(self) -> CFType where
Self: Sized, [src]
Self: Sized,
fn retain_count(&self) -> CFIndex[src]
fn type_of(&self) -> CFTypeID[src]
fn show(&self)[src]
fn instance_of<OtherCFType: TCFType>(&self) -> bool[src]
impl TCFType for CFType[src]
type Ref = CFTypeRef
fn as_concrete_TypeRef(&self) -> CFTypeRef[src]
unsafe fn wrap_under_get_rule(reference: CFTypeRef) -> CFType[src]
fn as_CFTypeRef(&self) -> CFTypeRef[src]
unsafe fn wrap_under_create_rule(obj: CFTypeRef) -> CFType[src]
fn type_id() -> CFTypeID[src]
fn as_CFType(&self) -> CFType[src]
fn into_CFType(self) -> CFType where
Self: Sized, [src]
Self: Sized,
fn retain_count(&self) -> CFIndex[src]
fn type_of(&self) -> CFTypeID[src]
fn show(&self)[src]
fn instance_of<OtherCFType: TCFType>(&self) -> bool[src]
impl TCFType for CFBoolean[src]
type Ref = CFBooleanRef
fn as_concrete_TypeRef(&self) -> CFBooleanRef[src]
unsafe fn wrap_under_get_rule(reference: CFBooleanRef) -> Self[src]
fn as_CFTypeRef(&self) -> CFTypeRef[src]
unsafe fn wrap_under_create_rule(reference: CFBooleanRef) -> Self[src]
fn type_id() -> CFTypeID[src]
fn as_CFType(&self) -> CFType[src]
fn into_CFType(self) -> CFType where
Self: Sized, [src]
Self: Sized,
fn retain_count(&self) -> CFIndex[src]
fn type_of(&self) -> CFTypeID[src]
fn show(&self)[src]
fn instance_of<OtherCFType: TCFType>(&self) -> bool[src]
impl TCFType for CFBundle[src]
type Ref = CFBundleRef
fn as_concrete_TypeRef(&self) -> CFBundleRef[src]
unsafe fn wrap_under_get_rule(reference: CFBundleRef) -> Self[src]
fn as_CFTypeRef(&self) -> CFTypeRef[src]
unsafe fn wrap_under_create_rule(reference: CFBundleRef) -> Self[src]
fn type_id() -> CFTypeID[src]
fn as_CFType(&self) -> CFType[src]
fn into_CFType(self) -> CFType where
Self: Sized, [src]
Self: Sized,
fn retain_count(&self) -> CFIndex[src]
fn type_of(&self) -> CFTypeID[src]
fn show(&self)[src]
fn instance_of<OtherCFType: TCFType>(&self) -> bool[src]
impl TCFType for CFData[src]
type Ref = CFDataRef
fn as_concrete_TypeRef(&self) -> CFDataRef[src]
unsafe fn wrap_under_get_rule(reference: CFDataRef) -> Self[src]
fn as_CFTypeRef(&self) -> CFTypeRef[src]
unsafe fn wrap_under_create_rule(reference: CFDataRef) -> Self[src]
fn type_id() -> CFTypeID[src]
fn as_CFType(&self) -> CFType[src]
fn into_CFType(self) -> CFType where
Self: Sized, [src]
Self: Sized,
fn retain_count(&self) -> CFIndex[src]
fn type_of(&self) -> CFTypeID[src]
fn show(&self)[src]
fn instance_of<OtherCFType: TCFType>(&self) -> bool[src]
impl TCFType for CFDate[src]
type Ref = CFDateRef
fn as_concrete_TypeRef(&self) -> CFDateRef[src]
unsafe fn wrap_under_get_rule(reference: CFDateRef) -> Self[src]
fn as_CFTypeRef(&self) -> CFTypeRef[src]
unsafe fn wrap_under_create_rule(reference: CFDateRef) -> Self[src]
fn type_id() -> CFTypeID[src]
fn as_CFType(&self) -> CFType[src]
fn into_CFType(self) -> CFType where
Self: Sized, [src]
Self: Sized,
fn retain_count(&self) -> CFIndex[src]
fn type_of(&self) -> CFTypeID[src]
fn show(&self)[src]
fn instance_of<OtherCFType: TCFType>(&self) -> bool[src]
impl TCFType for CFError[src]
type Ref = CFErrorRef
fn as_concrete_TypeRef(&self) -> CFErrorRef[src]
unsafe fn wrap_under_get_rule(reference: CFErrorRef) -> Self[src]
fn as_CFTypeRef(&self) -> CFTypeRef[src]
unsafe fn wrap_under_create_rule(reference: CFErrorRef) -> Self[src]
fn type_id() -> CFTypeID[src]
fn as_CFType(&self) -> CFType[src]
fn into_CFType(self) -> CFType where
Self: Sized, [src]
Self: Sized,
fn retain_count(&self) -> CFIndex[src]
fn type_of(&self) -> CFTypeID[src]
fn show(&self)[src]
fn instance_of<OtherCFType: TCFType>(&self) -> bool[src]
impl TCFType for CFFileDescriptor[src]
type Ref = CFFileDescriptorRef
fn as_concrete_TypeRef(&self) -> CFFileDescriptorRef[src]
unsafe fn wrap_under_get_rule(reference: CFFileDescriptorRef) -> Self[src]
fn as_CFTypeRef(&self) -> CFTypeRef[src]
unsafe fn wrap_under_create_rule(reference: CFFileDescriptorRef) -> Self[src]
fn type_id() -> CFTypeID[src]
fn as_CFType(&self) -> CFType[src]
fn into_CFType(self) -> CFType where
Self: Sized, [src]
Self: Sized,
fn retain_count(&self) -> CFIndex[src]
fn type_of(&self) -> CFTypeID[src]
fn show(&self)[src]
fn instance_of<OtherCFType: TCFType>(&self) -> bool[src]
impl TCFType for CFNumber[src]
type Ref = CFNumberRef
fn as_concrete_TypeRef(&self) -> CFNumberRef[src]
unsafe fn wrap_under_get_rule(reference: CFNumberRef) -> Self[src]
fn as_CFTypeRef(&self) -> CFTypeRef[src]
unsafe fn wrap_under_create_rule(reference: CFNumberRef) -> Self[src]
fn type_id() -> CFTypeID[src]
fn as_CFType(&self) -> CFType[src]
fn into_CFType(self) -> CFType where
Self: Sized, [src]
Self: Sized,
fn retain_count(&self) -> CFIndex[src]
fn type_of(&self) -> CFTypeID[src]
fn show(&self)[src]
fn instance_of<OtherCFType: TCFType>(&self) -> bool[src]
impl TCFType for CFRunLoop[src]
type Ref = CFRunLoopRef
fn as_concrete_TypeRef(&self) -> CFRunLoopRef[src]
unsafe fn wrap_under_get_rule(reference: CFRunLoopRef) -> Self[src]
fn as_CFTypeRef(&self) -> CFTypeRef[src]
unsafe fn wrap_under_create_rule(reference: CFRunLoopRef) -> Self[src]
fn type_id() -> CFTypeID[src]
fn as_CFType(&self) -> CFType[src]
fn into_CFType(self) -> CFType where
Self: Sized, [src]
Self: Sized,
fn retain_count(&self) -> CFIndex[src]
fn type_of(&self) -> CFTypeID[src]
fn show(&self)[src]
fn instance_of<OtherCFType: TCFType>(&self) -> bool[src]
impl TCFType for CFRunLoopObserver[src]
type Ref = CFRunLoopObserverRef
fn as_concrete_TypeRef(&self) -> CFRunLoopObserverRef[src]
unsafe fn wrap_under_get_rule(reference: CFRunLoopObserverRef) -> Self[src]
fn as_CFTypeRef(&self) -> CFTypeRef[src]
unsafe fn wrap_under_create_rule(reference: CFRunLoopObserverRef) -> Self[src]
fn type_id() -> CFTypeID[src]
fn as_CFType(&self) -> CFType[src]
fn into_CFType(self) -> CFType where
Self: Sized, [src]
Self: Sized,
fn retain_count(&self) -> CFIndex[src]
fn type_of(&self) -> CFTypeID[src]
fn show(&self)[src]
fn instance_of<OtherCFType: TCFType>(&self) -> bool[src]
impl TCFType for CFRunLoopSource[src]
type Ref = CFRunLoopSourceRef
fn as_concrete_TypeRef(&self) -> CFRunLoopSourceRef[src]
unsafe fn wrap_under_get_rule(reference: CFRunLoopSourceRef) -> Self[src]
fn as_CFTypeRef(&self) -> CFTypeRef[src]
unsafe fn wrap_under_create_rule(reference: CFRunLoopSourceRef) -> Self[src]
fn type_id() -> CFTypeID[src]
fn as_CFType(&self) -> CFType[src]
fn into_CFType(self) -> CFType where
Self: Sized, [src]
Self: Sized,
fn retain_count(&self) -> CFIndex[src]
fn type_of(&self) -> CFTypeID[src]
fn show(&self)[src]
fn instance_of<OtherCFType: TCFType>(&self) -> bool[src]
impl TCFType for CFRunLoopTimer[src]
type Ref = CFRunLoopTimerRef
fn as_concrete_TypeRef(&self) -> CFRunLoopTimerRef[src]
unsafe fn wrap_under_get_rule(reference: CFRunLoopTimerRef) -> Self[src]
fn as_CFTypeRef(&self) -> CFTypeRef[src]
unsafe fn wrap_under_create_rule(reference: CFRunLoopTimerRef) -> Self[src]
fn type_id() -> CFTypeID[src]
fn as_CFType(&self) -> CFType[src]
fn into_CFType(self) -> CFType where
Self: Sized, [src]
Self: Sized,
fn retain_count(&self) -> CFIndex[src]
fn type_of(&self) -> CFTypeID[src]
fn show(&self)[src]
fn instance_of<OtherCFType: TCFType>(&self) -> bool[src]
impl TCFType for CFString[src]
type Ref = CFStringRef
fn as_concrete_TypeRef(&self) -> CFStringRef[src]
unsafe fn wrap_under_get_rule(reference: CFStringRef) -> Self[src]
fn as_CFTypeRef(&self) -> CFTypeRef[src]
unsafe fn wrap_under_create_rule(reference: CFStringRef) -> Self[src]
fn type_id() -> CFTypeID[src]
fn as_CFType(&self) -> CFType[src]
fn into_CFType(self) -> CFType where
Self: Sized, [src]
Self: Sized,
fn retain_count(&self) -> CFIndex[src]
fn type_of(&self) -> CFTypeID[src]
fn show(&self)[src]
fn instance_of<OtherCFType: TCFType>(&self) -> bool[src]
impl TCFType for CFTimeZone[src]
type Ref = CFTimeZoneRef
fn as_concrete_TypeRef(&self) -> CFTimeZoneRef[src]
unsafe fn wrap_under_get_rule(reference: CFTimeZoneRef) -> Self[src]
fn as_CFTypeRef(&self) -> CFTypeRef[src]
unsafe fn wrap_under_create_rule(reference: CFTimeZoneRef) -> Self[src]
fn type_id() -> CFTypeID[src]
fn as_CFType(&self) -> CFType[src]
fn into_CFType(self) -> CFType where
Self: Sized, [src]
Self: Sized,
fn retain_count(&self) -> CFIndex[src]
fn type_of(&self) -> CFTypeID[src]
fn show(&self)[src]
fn instance_of<OtherCFType: TCFType>(&self) -> bool[src]
impl TCFType for CFURL[src]
type Ref = CFURLRef
fn as_concrete_TypeRef(&self) -> CFURLRef[src]
unsafe fn wrap_under_get_rule(reference: CFURLRef) -> Self[src]
fn as_CFTypeRef(&self) -> CFTypeRef[src]
unsafe fn wrap_under_create_rule(reference: CFURLRef) -> Self[src]
fn type_id() -> CFTypeID[src]
fn as_CFType(&self) -> CFType[src]
fn into_CFType(self) -> CFType where
Self: Sized, [src]
Self: Sized,
fn retain_count(&self) -> CFIndex[src]
fn type_of(&self) -> CFTypeID[src]
fn show(&self)[src]
fn instance_of<OtherCFType: TCFType>(&self) -> bool[src]
impl TCFType for CFUUID[src]
type Ref = CFUUIDRef
fn as_concrete_TypeRef(&self) -> CFUUIDRef[src]
unsafe fn wrap_under_get_rule(reference: CFUUIDRef) -> Self[src]
fn as_CFTypeRef(&self) -> CFTypeRef[src]
unsafe fn wrap_under_create_rule(reference: CFUUIDRef) -> Self[src]
fn type_id() -> CFTypeID[src]
fn as_CFType(&self) -> CFType[src]
fn into_CFType(self) -> CFType where
Self: Sized, [src]
Self: Sized,
fn retain_count(&self) -> CFIndex[src]
fn type_of(&self) -> CFTypeID[src]
fn show(&self)[src]
fn instance_of<OtherCFType: TCFType>(&self) -> bool[src]
impl<K, V> TCFType for CFDictionary<K, V>[src]
type Ref = CFDictionaryRef
fn as_concrete_TypeRef(&self) -> CFDictionaryRef[src]
unsafe fn wrap_under_get_rule(reference: CFDictionaryRef) -> Self[src]
fn as_CFTypeRef(&self) -> CFTypeRef[src]
unsafe fn wrap_under_create_rule(reference: CFDictionaryRef) -> Self[src]
fn type_id() -> CFTypeID[src]
fn as_CFType(&self) -> CFType[src]
fn into_CFType(self) -> CFType where
Self: Sized, [src]
Self: Sized,
fn retain_count(&self) -> CFIndex[src]
fn type_of(&self) -> CFTypeID[src]
fn show(&self)[src]
fn instance_of<OtherCFType: TCFType>(&self) -> bool[src]
impl<K, V> TCFType for CFMutableDictionary<K, V>[src]
type Ref = CFMutableDictionaryRef
fn as_concrete_TypeRef(&self) -> CFMutableDictionaryRef[src]
unsafe fn wrap_under_get_rule(reference: CFMutableDictionaryRef) -> Self[src]
fn as_CFTypeRef(&self) -> CFTypeRef[src]
unsafe fn wrap_under_create_rule(reference: CFMutableDictionaryRef) -> Self[src]
fn type_id() -> CFTypeID[src]
fn as_CFType(&self) -> CFType[src]
fn into_CFType(self) -> CFType where
Self: Sized, [src]
Self: Sized,
fn retain_count(&self) -> CFIndex[src]
fn type_of(&self) -> CFTypeID[src]
fn show(&self)[src]
fn instance_of<OtherCFType: TCFType>(&self) -> bool[src]
impl<T> TCFType for CFArray<T>[src]
type Ref = CFArrayRef
fn as_concrete_TypeRef(&self) -> CFArrayRef[src]
unsafe fn wrap_under_get_rule(reference: CFArrayRef) -> Self[src]
fn as_CFTypeRef(&self) -> CFTypeRef[src]
unsafe fn wrap_under_create_rule(reference: CFArrayRef) -> Self[src]
fn type_id() -> CFTypeID[src]
fn as_CFType(&self) -> CFType[src]
fn into_CFType(self) -> CFType where
Self: Sized, [src]
Self: Sized,
fn retain_count(&self) -> CFIndex[src]
fn type_of(&self) -> CFTypeID[src]
fn show(&self)[src]
fn instance_of<OtherCFType: TCFType>(&self) -> bool[src]
impl<T> TCFType for CFSet<T>[src]
type Ref = CFSetRef
fn as_concrete_TypeRef(&self) -> CFSetRef[src]
unsafe fn wrap_under_get_rule(reference: CFSetRef) -> Self[src]
fn as_CFTypeRef(&self) -> CFTypeRef[src]
unsafe fn wrap_under_create_rule(reference: CFSetRef) -> Self[src]
fn type_id() -> CFTypeID[src]
fn as_CFType(&self) -> CFType[src]
fn into_CFType(self) -> CFType where
Self: Sized, [src]
Self: Sized,